@@ -133,7 +133,7 @@ func (r *RunSingleCommand) Execute(c *cli.Context) {
 		logrus.Fatalln("Missing Executor")
 	}
 
-	executorProvider := common.GetExecutor(r.Executor)
+	executorProvider := common.GetExecutorProvider(r.Executor)
 	if executorProvider == nil {
 		logrus.Fatalln("Unknown executor:", r.Executor)
 	}
