@@ -47,8 +47,8 @@ func TestBuildRun(t *testing.T) {
 
 	// We run everything once
 	e.On("Prepare", mock.Anything, mock.Anything, mock.Anything).Return(nil).Once()
-	e.On("Finish", nil).Return().Once()
-	e.On("Cleanup").Return().Once()
+	e.On("Finish", nil).Once()
+	e.On("Cleanup").Once()
 
 	// Run script successfully
 	e.On("Shell").Return(&ShellScriptInfo{Shell: "script-shell"})
@@ -61,7 +61,7 @@ func TestBuildRun(t *testing.T) {
 	e.On("Run", matchBuildStage(BuildStageArchiveCache)).Return(nil).Once()
 	e.On("Run", matchBuildStage(BuildStageUploadOnSuccessArtifacts)).Return(nil).Once()
 
-	RegisterExecutor("build-run-test", &p)
+	RegisterExecutorProvider("build-run-test", &p)
 
 	successfulBuild, err := GetSuccessfulBuild()
 	assert.NoError(t, err)
@@ -106,8 +106,8 @@ func runSuccessfulMockBuild(t *testing.T, prepareFn func(options ExecutorPrepare
 
 	// We run everything once
 	e.On("Prepare", mock.Anything).Return(prepareFn).Once()
-	e.On("Finish", nil).Return().Once()
-	e.On("Cleanup").Return().Once()
+	e.On("Finish", nil).Once()
+	e.On("Cleanup").Once()
 
 	// Run script successfully
 	e.On("Shell").Return(&ShellScriptInfo{Shell: "script-shell"})
@@ -120,7 +120,7 @@ func runSuccessfulMockBuild(t *testing.T, prepareFn func(options ExecutorPrepare
 	e.On("Run", matchBuildStage(BuildStageArchiveCache)).Return(nil).Once()
 	e.On("Run", matchBuildStage(BuildStageUploadOnSuccessArtifacts)).Return(nil).Once()
 
-	RegisterExecutor(t.Name(), &p)
+	RegisterExecutorProvider(t.Name(), &p)
 
 	successfulBuild, err := GetSuccessfulBuild()
 	assert.NoError(t, err)
@@ -203,13 +203,13 @@ func TestBuildRunNoModifyConfig(t *testing.T) {
 	// Attempt to modify the Config object
 	e.On("Prepare", mock.Anything, mock.Anything, mock.Anything).
 		Return(func(options ExecutorPrepareOptions) error {
-			options.Config.Docker.DockerCredentials.Host = "10.0.0.2"
+			options.Config.Docker.Credentials.Host = "10.0.0.2"
 			return nil
 		}).Once()
 
 	// We run everything else once
-	e.On("Finish", nil).Return().Once()
-	e.On("Cleanup").Return().Once()
+	e.On("Finish", nil).Once()
+	e.On("Cleanup").Once()
 
 	// Run script successfully
 	e.On("Shell").Return(&ShellScriptInfo{Shell: "script-shell"})
@@ -222,7 +222,7 @@ func TestBuildRunNoModifyConfig(t *testing.T) {
 	e.On("Run", matchBuildStage(BuildStageArchiveCache)).Return(nil).Once()
 	e.On("Run", matchBuildStage(BuildStageUploadOnSuccessArtifacts)).Return(nil).Once()
 
-	RegisterExecutor("build-run-nomodify-test", &p)
+	RegisterExecutorProvider("build-run-nomodify-test", &p)
 
 	successfulBuild, err := GetSuccessfulBuild()
 	assert.NoError(t, err)
@@ -230,7 +230,7 @@ func TestBuildRunNoModifyConfig(t *testing.T) {
 		RunnerSettings: RunnerSettings{
 			Executor: "build-run-nomodify-test",
 			Docker: &DockerConfig{
-				DockerCredentials: docker_helpers.DockerCredentials{
+				Credentials: docker.Credentials{
 					Host: "10.0.0.1",
 				},
 			},
@@ -241,7 +241,7 @@ func TestBuildRunNoModifyConfig(t *testing.T) {
 
 	err = build.Run(&Config{}, &Trace{Writer: os.Stdout})
 	assert.NoError(t, err)
-	assert.Equal(t, "10.0.0.1", rc.Docker.DockerCredentials.Host)
+	assert.Equal(t, "10.0.0.1", rc.Docker.Credentials.Host)
 }
 
 func TestRetryPrepare(t *testing.T) {
@@ -265,14 +265,14 @@ func TestRetryPrepare(t *testing.T) {
 		Return(errors.New("prepare failed")).Twice()
 	e.On("Prepare", mock.Anything, mock.Anything, mock.Anything).
 		Return(nil).Once()
-	e.On("Cleanup").Return().Times(3)
+	e.On("Cleanup").Times(3)
 
 	// Succeed a build script
 	e.On("Shell").Return(&ShellScriptInfo{Shell: "script-shell"})
 	e.On("Run", mock.Anything).Return(nil)
-	e.On("Finish", nil).Return().Once()
+	e.On("Finish", nil).Once()
 
-	RegisterExecutor("build-run-retry-prepare", &p)
+	RegisterExecutorProvider("build-run-retry-prepare", &p)
 
 	successfulBuild, err := GetSuccessfulBuild()
 	assert.NoError(t, err)
@@ -307,9 +307,9 @@ func TestPrepareFailure(t *testing.T) {
 	// Prepare plan
 	e.On("Prepare", mock.Anything, mock.Anything, mock.Anything).
 		Return(errors.New("prepare failed")).Times(3)
-	e.On("Cleanup").Return().Times(3)
+	e.On("Cleanup").Times(3)
 
-	RegisterExecutor("build-run-prepare-failure", &p)
+	RegisterExecutorProvider("build-run-prepare-failure", &p)
 
 	successfulBuild, err := GetSuccessfulBuild()
 	assert.NoError(t, err)
@@ -342,9 +342,9 @@ func TestPrepareFailureOnBuildError(t *testing.T) {
 	// Prepare plan
 	e.On("Prepare", mock.Anything, mock.Anything, mock.Anything).
 		Return(&BuildError{}).Times(1)
-	e.On("Cleanup").Return().Times(1)
+	e.On("Cleanup").Times(1)
 
-	RegisterExecutor("build-run-prepare-failure-on-build-error", &p)
+	RegisterExecutorProvider("build-run-prepare-failure-on-build-error", &p)
 
 	successfulBuild, err := GetSuccessfulBuild()
 	assert.NoError(t, err)
@@ -377,15 +377,15 @@ func TestJobFailure(t *testing.T) {
 	// Prepare plan
 	e.On("Prepare", mock.Anything, mock.Anything, mock.Anything).
 		Return(nil).Times(1)
-	e.On("Cleanup").Return().Times(1)
+	e.On("Cleanup").Times(1)
 
 	// Succeed a build script
 	thrownErr := &BuildError{Inner: errors.New("test error")}
 	e.On("Shell").Return(&ShellScriptInfo{Shell: "script-shell"})
 	e.On("Run", mock.Anything).Return(thrownErr)
-	e.On("Finish", thrownErr).Return().Once()
+	e.On("Finish", thrownErr).Once()
 
-	RegisterExecutor("build-run-job-failure", p)
+	RegisterExecutorProvider("build-run-job-failure", p)
 
 	failedBuild, err := GetFailedBuild()
 	assert.NoError(t, err)
@@ -427,7 +427,7 @@ func TestJobFailureOnExecutionTimeout(t *testing.T) {
 	// Prepare plan
 	e.On("Prepare", mock.Anything, mock.Anything, mock.Anything).
 		Return(nil).Times(1)
-	e.On("Cleanup").Return().Times(1)
+	e.On("Cleanup").Times(1)
 
 	// Succeed a build script
 	e.On("Shell").Return(&ShellScriptInfo{Shell: "script-shell"})
@@ -435,9 +435,9 @@ func TestJobFailureOnExecutionTimeout(t *testing.T) {
 		time.Sleep(2 * time.Second)
 	}).Return(nil)
 	e.On("Run", mock.Anything).Return(nil)
-	e.On("Finish", mock.Anything).Return().Once()
+	e.On("Finish", mock.Anything).Once()
 
-	RegisterExecutor("build-run-job-failure-on-execution-timeout", p)
+	RegisterExecutorProvider("build-run-job-failure-on-execution-timeout", p)
 
 	successfulBuild, err := GetSuccessfulBuild()
 	assert.NoError(t, err)
@@ -489,7 +489,7 @@ func TestRunFailureRunsAfterScriptAndArtifactsOnFailure(t *testing.T) {
 
 	// Prepare plan
 	e.On("Prepare", mock.Anything, mock.Anything, mock.Anything).Return(nil)
-	e.On("Cleanup").Return().Once()
+	e.On("Cleanup").Once()
 
 	// Fail a build script
 	e.On("Shell").Return(&ShellScriptInfo{Shell: "script-shell"})
@@ -500,9 +500,9 @@ func TestRunFailureRunsAfterScriptAndArtifactsOnFailure(t *testing.T) {
 	e.On("Run", matchBuildStage(BuildStageUserScript)).Return(errors.New("build fail")).Once()
 	e.On("Run", matchBuildStage(BuildStageAfterScript)).Return(nil).Once()
 	e.On("Run", matchBuildStage(BuildStageUploadOnFailureArtifacts)).Return(nil).Once()
-	e.On("Finish", errors.New("build fail")).Return().Once()
+	e.On("Finish", errors.New("build fail")).Once()
 
-	RegisterExecutor("build-run-run-failure", &p)
+	RegisterExecutorProvider("build-run-run-failure", &p)
 
 	failedBuild, err := GetFailedBuild()
 	assert.NoError(t, err)
@@ -534,16 +534,16 @@ func TestGetSourcesRunFailure(t *testing.T) {
 
 	// Prepare plan
 	e.On("Prepare", mock.Anything, mock.Anything, mock.Anything).Return(nil)
-	e.On("Cleanup").Return()
+	e.On("Cleanup")
 
 	// Fail a build script
 	e.On("Shell").Return(&ShellScriptInfo{Shell: "script-shell"})
 	e.On("Run", matchBuildStage(BuildStagePrepare)).Return(nil).Once()
 	e.On("Run", matchBuildStage(BuildStageGetSources)).Return(errors.New("build fail")).Times(3)
 	e.On("Run", matchBuildStage(BuildStageUploadOnFailureArtifacts)).Return(nil).Once()
-	e.On("Finish", errors.New("build fail")).Return().Once()
+	e.On("Finish", errors.New("build fail")).Once()
 
-	RegisterExecutor("build-get-sources-run-failure", &p)
+	RegisterExecutorProvider("build-get-sources-run-failure", &p)
 
 	successfulBuild, err := GetSuccessfulBuild()
 	assert.NoError(t, err)
@@ -577,7 +577,7 @@ func TestArtifactDownloadRunFailure(t *testing.T) {
 
 	// Prepare plan
 	e.On("Prepare", mock.Anything, mock.Anything, mock.Anything).Return(nil)
-	e.On("Cleanup").Return()
+	e.On("Cleanup")
 
 	// Fail a build script
 	e.On("Shell").Return(&ShellScriptInfo{Shell: "script-shell"})
@@ -586,9 +586,9 @@ func TestArtifactDownloadRunFailure(t *testing.T) {
 	e.On("Run", matchBuildStage(BuildStageRestoreCache)).Return(nil).Once()
 	e.On("Run", matchBuildStage(BuildStageDownloadArtifacts)).Return(errors.New("build fail")).Times(3)
 	e.On("Run", matchBuildStage(BuildStageUploadOnFailureArtifacts)).Return(nil).Once()
-	e.On("Finish", errors.New("build fail")).Return().Once()
+	e.On("Finish", errors.New("build fail")).Once()
 
-	RegisterExecutor("build-artifacts-run-failure", &p)
+	RegisterExecutorProvider("build-artifacts-run-failure", &p)
 
 	successfulBuild, err := GetSuccessfulBuild()
 	assert.NoError(t, err)
@@ -622,7 +622,7 @@ func TestArtifactUploadRunFailure(t *testing.T) {
 
 	// Prepare plan
 	e.On("Prepare", mock.Anything, mock.Anything, mock.Anything).Return(nil)
-	e.On("Cleanup").Return()
+	e.On("Cleanup")
 
 	// Successful build script
 	e.On("Shell").Return(&ShellScriptInfo{Shell: "script-shell"}).Times(8)
@@ -634,9 +634,9 @@ func TestArtifactUploadRunFailure(t *testing.T) {
 	e.On("Run", matchBuildStage(BuildStageAfterScript)).Return(nil).Once()
 	e.On("Run", matchBuildStage(BuildStageArchiveCache)).Return(nil).Once()
 	e.On("Run", matchBuildStage(BuildStageUploadOnSuccessArtifacts)).Return(errors.New("upload fail")).Once()
-	e.On("Finish", errors.New("upload fail")).Return().Once()
+	e.On("Finish", errors.New("upload fail")).Once()
 
-	RegisterExecutor("build-upload-artifacts-run-failure", &p)
+	RegisterExecutorProvider("build-upload-artifacts-run-failure", &p)
 
 	successfulBuild, err := GetSuccessfulBuild()
 	successfulBuild.Artifacts = make(Artifacts, 1)
@@ -676,7 +676,7 @@ func TestRestoreCacheRunFailure(t *testing.T) {
 
 	// Prepare plan
 	e.On("Prepare", mock.Anything, mock.Anything, mock.Anything).Return(nil)
-	e.On("Cleanup").Return()
+	e.On("Cleanup")
 
 	// Fail a build script
 	e.On("Shell").Return(&ShellScriptInfo{Shell: "script-shell"})
@@ -684,9 +684,9 @@ func TestRestoreCacheRunFailure(t *testing.T) {
 	e.On("Run", matchBuildStage(BuildStageGetSources)).Return(nil).Once()
 	e.On("Run", matchBuildStage(BuildStageRestoreCache)).Return(errors.New("build fail")).Times(3)
 	e.On("Run", matchBuildStage(BuildStageUploadOnFailureArtifacts)).Return(nil).Once()
-	e.On("Finish", errors.New("build fail")).Return().Once()
+	e.On("Finish", errors.New("build fail")).Once()
 
-	RegisterExecutor("build-cache-run-failure", &p)
+	RegisterExecutorProvider("build-cache-run-failure", &p)
 
 	successfulBuild, err := GetSuccessfulBuild()
 	assert.NoError(t, err)
@@ -719,15 +719,15 @@ func TestRunWrongAttempts(t *testing.T) {
 
 	// Prepare plan
 	e.On("Prepare", mock.Anything, mock.Anything, mock.Anything).Return(nil)
-	e.On("Cleanup").Return()
+	e.On("Cleanup")
 
 	// Fail a build script
 	e.On("Shell").Return(&ShellScriptInfo{Shell: "script-shell"})
 	e.On("Run", mock.Anything).Return(nil).Once()
-	e.On("Run", mock.Anything).Return(errors.New("Number of attempts out of the range [1, 10] for stage: get_sources"))
-	e.On("Finish", errors.New("Number of attempts out of the range [1, 10] for stage: get_sources")).Return()
+	e.On("Run", mock.Anything).Return(errors.New("number of attempts out of the range [1, 10] for stage: get_sources"))
+	e.On("Finish", errors.New("number of attempts out of the range [1, 10] for stage: get_sources"))
 
-	RegisterExecutor("build-run-attempt-failure", &p)
+	RegisterExecutorProvider("build-run-attempt-failure", &p)
 
 	successfulBuild, err := GetSuccessfulBuild()
 	assert.NoError(t, err)
@@ -742,7 +742,7 @@ func TestRunWrongAttempts(t *testing.T) {
 
 	build.Variables = append(build.Variables, JobVariable{Key: "GET_SOURCES_ATTEMPTS", Value: "0"})
 	err = build.Run(&Config{}, &Trace{Writer: os.Stdout})
-	assert.EqualError(t, err, "Number of attempts out of the range [1, 10] for stage: get_sources")
+	assert.EqualError(t, err, "number of attempts out of the range [1, 10] for stage: get_sources")
 }
 
 func TestRunSuccessOnSecondAttempt(t *testing.T) {
@@ -758,8 +758,8 @@ func TestRunSuccessOnSecondAttempt(t *testing.T) {
 
 	// We run everything once
 	e.On("Prepare", mock.Anything, mock.Anything, mock.Anything).Return(nil).Once()
-	e.On("Finish", mock.Anything).Return().Twice()
-	e.On("Cleanup").Return().Twice()
+	e.On("Finish", mock.Anything).Twice()
+	e.On("Cleanup").Twice()
 
 	// Run script successfully
 	e.On("Shell").Return(&ShellScriptInfo{Shell: "script-shell"})
@@ -768,7 +768,7 @@ func TestRunSuccessOnSecondAttempt(t *testing.T) {
 	e.On("Run", mock.Anything).Return(errors.New("build fail")).Once()
 	e.On("Run", mock.Anything).Return(nil)
 
-	RegisterExecutor("build-run-success-second-attempt", &p)
+	RegisterExecutorProvider("build-run-success-second-attempt", &p)
 
 	successfulBuild, err := GetSuccessfulBuild()
 	assert.NoError(t, err)
@@ -1181,7 +1181,7 @@ func TestWaitForTerminal(t *testing.T) {
 			},
 			jobTimeout:             3600,
 			waitForTerminalTimeout: time.Second,
-			expectedErr:            "Terminal session timed out (maximum time allowed - 1s)",
+			expectedErr:            "terminal session timed out (maximum time allowed - 1s)",
 		},
 		{
 			name: "System Interrupt",
@@ -1453,3 +1453,111 @@ func TestBuildFinishTimeout(t *testing.T) {
 	}
 
 }
+
+func TestProjectUniqueName(t *testing.T) {
+	tests := map[string]struct {
+		build        Build
+		expectedName string
+	}{
+		"project non rfc1132 unique name": {
+			build: Build{
+				Runner: &RunnerConfig{
+					RunnerCredentials: RunnerCredentials{
+						Token: "Ze_n8E6en622WxxSg4r8",
+					},
+				},
+				JobResponse: JobResponse{
+					JobInfo: JobInfo{
+						ProjectID: 1234567890,
+					},
+				},
+				ProjectRunnerID: 0,
+			},
+			expectedName: "runner-zen8e6e-project-1234567890-concurrent-0",
+		},
+		"project non rfc1132 unique name longer than 63 char": {
+			build: Build{
+				Runner: &RunnerConfig{
+					RunnerCredentials: RunnerCredentials{
+						Token: "Ze_n8E6en622WxxSg4r8",
+					},
+				},
+				JobResponse: JobResponse{
+					JobInfo: JobInfo{
+						ProjectID: 123456789012345,
+					},
+				},
+				ProjectRunnerID: 123456789012345,
+			},
+			expectedName: "runner-zen8e6e-project-123456789012345-concurrent-1234567890123",
+		},
+		"project normal unique name": {
+			build: Build{
+				Runner: &RunnerConfig{
+					RunnerCredentials: RunnerCredentials{
+						Token: "xYzWabc-Ij3xlKjmoPO9",
+					},
+				},
+				JobResponse: JobResponse{
+					JobInfo: JobInfo{
+						ProjectID: 1234567890,
+					},
+				},
+				ProjectRunnerID: 0,
+			},
+			expectedName: "runner-xyzwabc--project-1234567890-concurrent-0",
+		},
+	}
+
+	for name, test := range tests {
+		t.Run(name, func(t *testing.T) {
+			assert.Equal(t, test.expectedName, test.build.ProjectUniqueName())
+		})
+	}
+}
+
+func TestBuild_GetExecutorJobSectionAttempts(t *testing.T) {
+	tests := []struct {
+		attempts         string
+		expectedAttempts int
+		expectedErr      error
+	}{
+		{
+			attempts:         "",
+			expectedAttempts: 1,
+		},
+		{
+			attempts:         "3",
+			expectedAttempts: 3,
+		},
+		{
+			attempts:         "0",
+			expectedAttempts: 0,
+			expectedErr:      &invalidAttemptError{},
+		},
+		{
+			attempts:         "99",
+			expectedAttempts: 0,
+			expectedErr:      &invalidAttemptError{},
+		},
+	}
+
+	for _, tt := range tests {
+		t.Run(tt.attempts, func(t *testing.T) {
+			build := Build{
+				JobResponse: JobResponse{
+					Variables: JobVariables{
+						JobVariable{
+							Key:   ExecutorJobSectionAttempts,
+							Value: tt.attempts,
+						},
+					},
+				},
+			}
+
+			attempts, err := build.GetExecutorJobSectionAttempts()
+			assert.True(t, errors.Is(err, tt.expectedErr))
+			assert.Equal(t, tt.expectedAttempts, attempts)
+		})
+	}
+}
