@@ -23,7 +23,6 @@ import (
 	"github.com/kardianos/osext"
 	"github.com/mattn/go-zglob"
 	"github.com/sirupsen/logrus"
-	"gitlab.com/gitlab-org/gitlab-runner/helpers/container/services"
 
 	"gitlab.com/gitlab-org/gitlab-runner/common"
 	"gitlab.com/gitlab-org/gitlab-runner/executors"
@@ -32,7 +31,8 @@ import (
 	"gitlab.com/gitlab-org/gitlab-runner/executors/docker/internal/volumes/parser"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/container/helperimage"
-	docker_helpers "gitlab.com/gitlab-org/gitlab-runner/helpers/docker"
+	"gitlab.com/gitlab-org/gitlab-runner/helpers/container/services"
+	"gitlab.com/gitlab-org/gitlab-runner/helpers/docker"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/featureflags"
 )
 
@@ -62,7 +62,7 @@ var errNetworksManagerUndefined = errors.New("networksManager is undefined")
 
 type executor struct {
 	executors.AbstractExecutor
-	client       docker_helpers.Client
+	client       docker.Client
 	volumeParser parser.Parser
 	info         types.Info
 
@@ -84,6 +84,8 @@ type executor struct {
 	networksManager networks.Manager
 
 	networkMode container.NetworkMode
+
+	projectUniqRandomizedName string
 }
 
 func init() {
@@ -108,13 +110,13 @@ func (e *executor) getUserAuthConfiguration(indexName string) (string, *types.Au
 	}
 
 	buf := bytes.NewBufferString(e.Build.GetDockerAuthConfig())
-	authConfigs, _ := docker_helpers.ReadAuthConfigsFromReader(buf)
+	authConfigs, _ := docker.ReadAuthConfigsFromReader(buf)
 
 	if authConfigs == nil {
 		return "", nil
 	}
 
-	return AuthConfigSourceNameUserVariable, docker_helpers.ResolveDockerAuthConfig(indexName, authConfigs)
+	return AuthConfigSourceNameUserVariable, docker.ResolveDockerAuthConfig(indexName, authConfigs)
 }
 
 func (e *executor) getBuildAuthConfiguration(indexName string) (string, *types.AuthConfig) {
@@ -136,23 +138,23 @@ func (e *executor) getBuildAuthConfiguration(indexName string) (string, *types.A
 		}
 	}
 
-	return AuthConfigSourceNameJobPayload, docker_helpers.ResolveDockerAuthConfig(indexName, authConfigs)
+	return AuthConfigSourceNameJobPayload, docker.ResolveDockerAuthConfig(indexName, authConfigs)
 }
 
 func (e *executor) getHomeDirAuthConfiguration(indexName string) (string, *types.AuthConfig) {
-	sourceFile, authConfigs, _ := docker_helpers.ReadDockerAuthConfigsFromHomeDir(e.Shell().User)
+	sourceFile, authConfigs, _ := docker.ReadDockerAuthConfigsFromHomeDir(e.Shell().User)
 
 	if authConfigs == nil {
 		return "", nil
 	}
-	return sourceFile, docker_helpers.ResolveDockerAuthConfig(indexName, authConfigs)
+	return sourceFile, docker.ResolveDockerAuthConfig(indexName, authConfigs)
 
 }
 
 type authConfigResolver func(indexName string) (string, *types.AuthConfig)
 
 func (e *executor) getAuthConfig(imageName string) *types.AuthConfig {
-	indexName, _ := docker_helpers.SplitDockerImageName(imageName)
+	indexName, _ := docker.SplitDockerImageName(imageName)
 
 	resolvers := []authConfigResolver{
 		e.getUserAuthConfiguration,
@@ -189,7 +191,7 @@ func (e *executor) pullDockerImage(imageName string, ac *types.AuthConfig) (*typ
 
 	options := types.ImagePullOptions{}
 	if ac != nil {
-		options.RegistryAuth, _ = docker_helpers.EncodeAuthConfig(ac)
+		options.RegistryAuth, _ = docker.EncodeAuthConfig(ac)
 	}
 
 	errorRegexp := regexp.MustCompile("(repository does not exist|not found)")
@@ -268,7 +270,7 @@ func (e *executor) loadPrebuiltImage(path, ref, tag string) (*types.ImageInspect
 			return nil, err
 		}
 
-		return nil, fmt.Errorf("Cannot load prebuilt image: %s: %w", path, err)
+		return nil, fmt.Errorf("cannot load prebuilt image: %s: %w", path, err)
 	}
 	defer file.Close()
 
@@ -281,7 +283,7 @@ func (e *executor) loadPrebuiltImage(path, ref, tag string) (*types.ImageInspect
 	options := types.ImageImportOptions{Tag: tag}
 
 	if err := e.client.ImageImportBlocking(e.Context, source, ref, options); err != nil {
-		return nil, fmt.Errorf("Failed to import image: %w", err)
+		return nil, fmt.Errorf("failed to import image: %w", err)
 	}
 
 	image, _, err := e.client.ImageInspectWithRaw(e.Context, ref+":"+tag)
@@ -383,7 +385,7 @@ func (e *executor) parseDeviceString(deviceString string) (device container.Devi
 	parts := strings.Split(deviceString, ":")
 
 	if len(parts) > 3 {
-		err = fmt.Errorf("Too many colons")
+		err = fmt.Errorf("too many colons")
 		return
 	}
 
@@ -412,7 +414,7 @@ func (e *executor) bindDevices() (err error) {
 	for _, deviceString := range e.Config.Docker.Devices {
 		device, err := e.parseDeviceString(deviceString)
 		if err != nil {
-			err = fmt.Errorf("Failed to parse device string %q: %w", deviceString, err)
+			err = fmt.Errorf("failed to parse device string %q: %w", deviceString, err)
 			return err
 		}
 
@@ -461,7 +463,7 @@ func (e *executor) createService(serviceIndex int, service, version, image strin
 	}
 
 	serviceSlug := strings.Replace(service, "/", "__", -1)
-	containerName := fmt.Sprintf("%s-%s-%d", e.Build.ProjectUniqueName(), serviceSlug, serviceIndex)
+	containerName := fmt.Sprintf("%s-%s-%d", e.getProjectUniqRandomizedName(), serviceSlug, serviceIndex)
 
 	// this will fail potentially some builds if there's name collision
 	e.removeContainer(e.Context, containerName)
@@ -486,7 +488,6 @@ func (e *executor) createService(serviceIndex int, service, version, image strin
 		NetworkMode:   e.networkMode,
 		Binds:         e.volumesManager.Binds(),
 		ShmSize:       e.Config.Docker.ShmSize,
-		VolumesFrom:   e.volumesManager.ContainerIDs(),
 		Tmpfs:         e.Config.Docker.ServicesTmpfs,
 		LogConfig: container.LogConfig{
 			Type: "json-file",
@@ -501,7 +502,7 @@ func (e *executor) createService(serviceIndex int, service, version, image strin
 		return nil, err
 	}
 
-	e.Debugln("Starting service container", resp.ID, "...")
+	e.Debugln(fmt.Sprintf("Starting service container %s (%s)...", containerName, resp.ID))
 	err = e.client.ContainerStart(e.Context, resp.ID, types.ContainerStartOptions{})
 	if err != nil {
 		e.temporary = append(e.temporary, resp.ID)
@@ -523,6 +524,15 @@ func (e *executor) networkConfig(aliases []string) *network.NetworkingConfig {
 	}
 }
 
+func (e *executor) getProjectUniqRandomizedName() string {
+	if e.projectUniqRandomizedName == "" {
+		uuid, _ := helpers.GenerateRandomUUID(8)
+		e.projectUniqRandomizedName = fmt.Sprintf("%s-%s", e.Build.ProjectUniqueName(), uuid)
+	}
+
+	return e.projectUniqRandomizedName
+}
+
 func (e *executor) getServicesDefinitions() (common.Services, error) {
 	internalServiceImages := []string{}
 	serviceDefinitions := common.Services{}
@@ -709,7 +719,7 @@ func (e *executor) createContainer(containerType string, imageDefinition common.
 
 	// Always create unique, but sequential name
 	containerIndex := len(e.builds)
-	containerName := e.Build.ProjectUniqueName() + "-" +
+	containerName := e.getProjectUniqRandomizedName() + "-" +
 		containerType + "-" + strconv.Itoa(containerIndex)
 
 	config := &container.Config{
@@ -733,15 +743,6 @@ func (e *executor) createContainer(containerType string, imageDefinition common.
 		return nil, err
 	}
 
-	// By default we use caches container,
-	// but in later phases we hook to previous build container
-	volumesFrom := e.volumesManager.ContainerIDs()
-	if len(e.builds) > 0 {
-		volumesFrom = []string{
-			e.builds[len(e.builds)-1],
-		}
-	}
-
 	hostConfig := &container.HostConfig{
 		Resources: container.Resources{
 			Memory:            e.Config.Docker.GetMemory(),
@@ -769,7 +770,7 @@ func (e *executor) createContainer(containerType string, imageDefinition common.
 		OomScoreAdj:   e.Config.Docker.OomScoreAdjust,
 		ShmSize:       e.Config.Docker.ShmSize,
 		VolumeDriver:  e.Config.Docker.VolumeDriver,
-		VolumesFrom:   append(e.Config.Docker.VolumesFrom, volumesFrom...),
+		VolumesFrom:   append(e.Config.Docker.VolumesFrom),
 		LogConfig: container.LogConfig{
 			Type: "json-file",
 		},
@@ -829,7 +830,7 @@ func (e *executor) waitForContainer(ctx context.Context, id string) error {
 	for ctx.Err() == nil {
 		container, err := e.client.ContainerInspect(ctx, id)
 		if err != nil {
-			if docker_helpers.IsErrNotFound(err) {
+			if docker.IsErrNotFound(err) {
 				return err
 			}
 
@@ -911,7 +912,7 @@ func (e *executor) watchContainer(ctx context.Context, id string, input io.Reade
 	select {
 	case <-ctx.Done():
 		e.killContainer(id, waitCh)
-		err = errors.New("Aborted")
+		err = errors.New("aborted")
 
 	case err = <-attachCh:
 		e.killContainer(id, waitCh)
@@ -924,21 +925,32 @@ func (e *executor) watchContainer(ctx context.Context, id string, input io.Reade
 }
 
 func (e *executor) removeContainer(ctx context.Context, id string) error {
+	e.Debugln("Removing container", id)
+
 	e.disconnectNetwork(ctx, id)
+
 	options := types.ContainerRemoveOptions{
 		RemoveVolumes: true,
 		Force:         true,
 	}
+
 	err := e.client.ContainerRemove(ctx, id, options)
-	e.Debugln("Removed container", id, "with", err)
-	return err
+	if err != nil {
+		e.Debugln("Removing container", id, "finished with error", err)
+		return err
+	}
+
+	e.Debugln("Removed container", id)
+	return nil
 }
 
-func (e *executor) disconnectNetwork(ctx context.Context, id string) error {
+func (e *executor) disconnectNetwork(ctx context.Context, id string) {
+	e.Debugln("Disconnecting container", id, "from networks")
+
 	netList, err := e.client.NetworkList(ctx, types.NetworkListOptions{})
 	if err != nil {
 		e.Debugln("Can't get network list. ListNetworks exited with", err)
-		return err
+		return
 	}
 
 	for _, network := range netList {
@@ -954,7 +966,7 @@ func (e *executor) disconnectNetwork(ctx context.Context, id string) error {
 			}
 		}
 	}
-	return err
+	return
 }
 
 func (e *executor) verifyAllowedImage(image, optionName string, allowedImages []string, internalImages []string) error {
@@ -999,7 +1011,7 @@ func (e *executor) expandImageName(imageName string, allowedInternalImages []str
 	}
 
 	if e.Config.Docker.Image == "" {
-		return "", errors.New("No Docker image specified to run the build in")
+		return "", errors.New("no Docker image specified to run the build in")
 	}
 
 	return e.Config.Docker.Image, nil
@@ -1018,7 +1030,7 @@ func (e *executor) overwriteEntrypoint(image *common.Image) []string {
 }
 
 func (e *executor) connectDocker() error {
-	client, err := docker_helpers.New(e.Config.Docker.DockerCredentials, "")
+	client, err := docker.New(e.Config.Docker.Credentials, "")
 	if err != nil {
 		return err
 	}
@@ -1104,8 +1116,8 @@ func (e *executor) createVolumes() error {
 	}
 
 	for _, volume := range e.Config.Docker.Volumes {
-		err := e.volumesManager.Create(volume)
-		if err == volumes.ErrCacheVolumesDisabled {
+		err := e.volumesManager.Create(e.Context, volume)
+		if errors.Is(err, volumes.ErrCacheVolumesDisabled) {
 			e.Warningln(fmt.Sprintf(
 				"Container based cache volumes creation is disabled. Will not create volume for %q",
 				volume,
@@ -1142,20 +1154,21 @@ func (e *executor) createBuildVolume() error {
 	var err error
 
 	if e.Build.GetGitStrategy() == common.GitFetch {
-		err = e.volumesManager.Create(jobsDir)
+		err = e.volumesManager.Create(e.Context, jobsDir)
 		if err == nil {
 			return nil
 		}
 
-		if err == volumes.ErrCacheVolumesDisabled {
-			err = e.volumesManager.CreateTemporary(jobsDir)
+		if errors.Is(err, volumes.ErrCacheVolumesDisabled) {
+			err = e.volumesManager.CreateTemporary(e.Context, jobsDir)
 		}
 	} else {
-		err = e.volumesManager.CreateTemporary(jobsDir)
+		err = e.volumesManager.CreateTemporary(e.Context, jobsDir)
 	}
 
 	if err != nil {
-		if _, ok := err.(*volumes.ErrVolumeAlreadyDefined); !ok {
+		var volDefinedErr *volumes.ErrVolumeAlreadyDefined
+		if !errors.As(err, &volDefinedErr) {
 			return err
 		}
 	}
@@ -1247,10 +1260,6 @@ func (e *executor) Cleanup() {
 		remove(temporaryID)
 	}
 
-	if e.volumesManager != nil {
-		<-e.volumesManager.Cleanup(ctx)
-	}
-
 	wg.Wait()
 
 	err := e.cleanupNetwork(ctx)
@@ -1313,15 +1322,17 @@ func (e *executor) runServiceHealthCheckContainer(service *types.Container, time
 		},
 	}
 
-	e.Debugln("Waiting for service container", containerName, "to be up and running...")
+	e.Debugln(fmt.Sprintf("Creating service healthcheck container %s...", containerName))
 	resp, err := e.client.ContainerCreate(e.Context, config, hostConfig, nil, containerName)
 	if err != nil {
-		return fmt.Errorf("ContainerCreate: %w", err)
+		return fmt.Errorf("create service container: %w", err)
 	}
 	defer e.removeContainer(e.Context, resp.ID)
+
+	e.Debugln(fmt.Sprintf("Starting service healthcheck container %s (%s)...", containerName, resp.ID))
 	err = e.client.ContainerStart(e.Context, resp.ID, types.ContainerStartOptions{})
 	if err != nil {
-		return fmt.Errorf("ContainerStart: %w", err)
+		return fmt.Errorf("start service container: %w", err)
 	}
 
 	waitResult := make(chan error, 1)
