@@ -9,6 +9,7 @@ import (
 	"io/ioutil"
 	"os"
 	"path"
+	"regexp"
 	"strings"
 	"sync"
 	"testing"
@@ -30,7 +31,7 @@ import (
 	"gitlab.com/gitlab-org/gitlab-runner/helpers"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/container/helperimage"
 	service_test "gitlab.com/gitlab-org/gitlab-runner/helpers/container/services/test"
-	docker_helpers "gitlab.com/gitlab-org/gitlab-runner/helpers/docker"
+	"gitlab.com/gitlab-org/gitlab-runner/helpers/docker"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/featureflags"
 )
 
@@ -144,14 +145,20 @@ func TestVerifyAllowedImage(t *testing.T) {
 }
 
 func testServiceFromNamedImage(t *testing.T, description, imageName, serviceName string) {
-	var c docker_helpers.MockClient
+	c := new(docker.MockClient)
 	defer c.AssertExpectations(t)
 
-	containerName := fmt.Sprintf("runner-abcdef12-project-0-concurrent-0-%s-0", strings.Replace(serviceName, "/", "__", -1))
+	servicePart := fmt.Sprintf("-%s-0", strings.Replace(serviceName, "/", "__", -1))
+	containerNameRegex, err := regexp.Compile("runner-abcdef12-project-0-concurrent-0-[^-]+" + servicePart)
+	require.NoError(t, err)
+
+	containerNameMatcher := mock.MatchedBy(func(containerName string) bool {
+		return containerNameRegex.MatchString(containerName)
+	})
 	networkID := "network-id"
 
 	e := executor{
-		client: &c,
+		client: c,
 		info: types.Info{
 			OSType:       helperimage.OSTypeLinux,
 			Architecture: "amd64",
@@ -169,7 +176,7 @@ func testServiceFromNamedImage(t *testing.T, description, imageName, serviceName
 	e.Build.JobInfo.ProjectID = 0
 	e.Build.Runner.Token = "abcdef1234567890"
 	e.Context = context.Background()
-	var err error
+
 	e.helperImageInfo, err = helperimage.Get(common.REVISION, helperimage.Config{
 		OSType:          e.info.OSType,
 		Architecture:    e.info.Architecture,
@@ -181,6 +188,8 @@ func testServiceFromNamedImage(t *testing.T, description, imageName, serviceName
 		Environment: []string{},
 	}
 
+	realServiceContainerName := e.getProjectUniqRandomizedName() + servicePart
+
 	c.On("ImagePullBlocking", e.Context, imageName, options).
 		Return(nil).
 		Once()
@@ -189,28 +198,24 @@ func testServiceFromNamedImage(t *testing.T, description, imageName, serviceName
 		Return(types.ImageInspect{ID: "image-id"}, nil, nil).
 		Twice()
 
-	c.On("ContainerRemove", e.Context, containerName, types.ContainerRemoveOptions{RemoveVolumes: true, Force: true}).
+	c.On("ContainerRemove", e.Context, containerNameMatcher, types.ContainerRemoveOptions{RemoveVolumes: true, Force: true}).
 		Return(nil).
 		Once()
 
 	networkContainersMap := map[string]types.EndpointResource{
-		"1": {Name: containerName},
+		"1": {Name: realServiceContainerName},
 	}
 
 	c.On("NetworkList", e.Context, types.NetworkListOptions{}).
 		Return([]types.NetworkResource{{ID: networkID, Name: "network-name", Containers: networkContainersMap}}, nil).
 		Once()
 
-	c.On("NetworkDisconnect", e.Context, networkID, containerName, true).
+	c.On("NetworkDisconnect", e.Context, networkID, containerNameMatcher, true).
 		Return(nil).
 		Once()
 
-	c.On("ImageInspectWithRaw", mock.Anything, "gitlab/gitlab-runner-helper:x86_64-latest").
-		Return(types.ImageInspect{ID: "helper-image-id"}, nil, nil).
-		Once()
-
 	c.On("ContainerCreate", mock.Anything, mock.Anything, mock.Anything, mock.Anything, mock.Anything).
-		Return(container.ContainerCreateCreatedBody{ID: containerName}, nil).
+		Return(container.ContainerCreateCreatedBody{ID: realServiceContainerName}, nil).
 		Once()
 
 	c.On("ContainerStart", e.Context, mock.Anything, mock.Anything).
@@ -234,11 +239,11 @@ func TestServiceFromNamedImage(t *testing.T) {
 }
 
 func TestDockerForNamedImage(t *testing.T) {
-	var c docker_helpers.MockClient
+	c := new(docker.MockClient)
 	defer c.AssertExpectations(t)
 	validSHA := "real@sha256:b5bb9d8014a0f9b1d61e21e796d78dccdf1352f23cd32812f4850b878ae4944c"
 
-	e := executor{client: &c}
+	e := executor{client: c}
 	e.Context = context.Background()
 	options := buildImagePullOptions(e, "test")
 
@@ -268,10 +273,10 @@ func TestDockerForNamedImage(t *testing.T) {
 }
 
 func TestDockerForExistingImage(t *testing.T) {
-	var c docker_helpers.MockClient
+	c := new(docker.MockClient)
 	defer c.AssertExpectations(t)
 
-	e := executor{client: &c}
+	e := executor{client: c}
 	e.Context = context.Background()
 	options := buildImagePullOptions(e, "existing")
 
@@ -289,7 +294,7 @@ func TestDockerForExistingImage(t *testing.T) {
 }
 
 func TestHelperImageWithVariable(t *testing.T) {
-	c := new(docker_helpers.MockClient)
+	c := new(docker.MockClient)
 	defer c.AssertExpectations(t)
 
 	c.On("ImageInspectWithRaw", mock.Anything, "gitlab/gitlab-runner:HEAD").
@@ -333,11 +338,11 @@ func (e *executor) setPolicyMode(pullPolicy common.DockerPullPolicy) {
 }
 
 func TestDockerGetImageById(t *testing.T) {
-	var c docker_helpers.MockClient
+	c := new(docker.MockClient)
 	defer c.AssertExpectations(t)
 
 	// Use default policy
-	e := executor{client: &c}
+	e := executor{client: c}
 	e.Context = context.Background()
 	e.setPolicyMode("")
 
@@ -352,10 +357,10 @@ func TestDockerGetImageById(t *testing.T) {
 }
 
 func TestDockerUnknownPolicyMode(t *testing.T) {
-	var c docker_helpers.MockClient
+	c := new(docker.MockClient)
 	defer c.AssertExpectations(t)
 
-	e := executor{client: &c}
+	e := executor{client: c}
 	e.Context = context.Background()
 	e.setPolicyMode("unknown")
 
@@ -364,10 +369,10 @@ func TestDockerUnknownPolicyMode(t *testing.T) {
 }
 
 func TestDockerPolicyModeNever(t *testing.T) {
-	var c docker_helpers.MockClient
+	c := new(docker.MockClient)
 	defer c.AssertExpectations(t)
 
-	e := executor{client: &c}
+	e := executor{client: c}
 	e.Context = context.Background()
 	e.setPolicyMode(common.PullPolicyNever)
 
@@ -388,10 +393,10 @@ func TestDockerPolicyModeNever(t *testing.T) {
 }
 
 func TestDockerPolicyModeIfNotPresentForExistingImage(t *testing.T) {
-	var c docker_helpers.MockClient
+	c := new(docker.MockClient)
 	defer c.AssertExpectations(t)
 
-	e := executor{client: &c}
+	e := executor{client: c}
 	e.Context = context.Background()
 	e.setPolicyMode(common.PullPolicyIfNotPresent)
 
@@ -405,10 +410,10 @@ func TestDockerPolicyModeIfNotPresentForExistingImage(t *testing.T) {
 }
 
 func TestDockerPolicyModeIfNotPresentForNotExistingImage(t *testing.T) {
-	var c docker_helpers.MockClient
+	c := new(docker.MockClient)
 	defer c.AssertExpectations(t)
 
-	e := executor{client: &c}
+	e := executor{client: c}
 	e.Context = context.Background()
 	e.setPolicyMode(common.PullPolicyIfNotPresent)
 
@@ -440,10 +445,10 @@ func TestDockerPolicyModeIfNotPresentForNotExistingImage(t *testing.T) {
 }
 
 func TestDockerPolicyModeAlwaysForExistingImage(t *testing.T) {
-	var c docker_helpers.MockClient
+	c := new(docker.MockClient)
 	defer c.AssertExpectations(t)
 
-	e := executor{client: &c}
+	e := executor{client: c}
 	e.Context = context.Background()
 	e.setPolicyMode(common.PullPolicyAlways)
 
@@ -466,10 +471,10 @@ func TestDockerPolicyModeAlwaysForExistingImage(t *testing.T) {
 }
 
 func TestDockerPolicyModeAlwaysForLocalOnlyImage(t *testing.T) {
-	var c docker_helpers.MockClient
+	c := new(docker.MockClient)
 	defer c.AssertExpectations(t)
 
-	e := executor{client: &c}
+	e := executor{client: c}
 	e.Context = context.Background()
 	e.setPolicyMode(common.PullPolicyAlways)
 
@@ -488,10 +493,10 @@ func TestDockerPolicyModeAlwaysForLocalOnlyImage(t *testing.T) {
 }
 
 func TestDockerGetExistingDockerImageIfPullFails(t *testing.T) {
-	var c docker_helpers.MockClient
+	c := new(docker.MockClient)
 	defer c.AssertExpectations(t)
 
-	e := executor{client: &c}
+	e := executor{client: c}
 	e.Context = context.Background()
 	e.setPolicyMode(common.PullPolicyAlways)
 
@@ -615,7 +620,7 @@ type volumesTestCase struct {
 	gitStrategy              string
 	adjustConfiguration      func(e *executor)
 	volumesManagerAssertions func(*volumes.MockManager)
-	clientAssertions         func(*docker_helpers.MockClient)
+	clientAssertions         func(*docker.MockClient)
 	createVolumeManager      bool
 	expectedError            error
 }
@@ -624,7 +629,7 @@ var volumesTestsDefaultBuildsDir = "/default-builds-dir"
 var volumesTestsDefaultCacheDir = "/default-cache-dir"
 
 func getExecutorForVolumesTests(t *testing.T, test volumesTestCase) (*executor, func()) {
-	clientMock := new(docker_helpers.MockClient)
+	clientMock := new(docker.MockClient)
 	volumesManagerMock := new(volumes.MockManager)
 
 	oldCreateVolumesManager := createVolumesManager
@@ -733,7 +738,7 @@ func TestCreateVolumes(t *testing.T) {
 			volumes:     []string{"/volume"},
 			gitStrategy: "clone",
 			volumesManagerAssertions: func(vm *volumes.MockManager) {
-				vm.On("Create", "/volume").
+				vm.On("Create", mock.Anything, "/volume").
 					Return(nil).
 					Once()
 			},
@@ -743,17 +748,27 @@ func TestCreateVolumes(t *testing.T) {
 			volumes:     []string{"/volume"},
 			gitStrategy: "clone",
 			volumesManagerAssertions: func(vm *volumes.MockManager) {
-				vm.On("Create", "/volume").
+				vm.On("Create", mock.Anything, "/volume").
 					Return(volumes.ErrCacheVolumesDisabled).
 					Once()
 			},
 			createVolumeManager: true,
 		},
+		"volumes defined, empty buildsDir, clone strategy, cache containers disabled wrapped error on user volume": {
+			volumes:     []string{"/volume"},
+			gitStrategy: "clone",
+			volumesManagerAssertions: func(vm *volumes.MockManager) {
+				vm.On("Create", mock.Anything, "/volume").
+					Return(fmt.Errorf("wrap: %w", volumes.ErrCacheVolumesDisabled)).
+					Once()
+			},
+			createVolumeManager: true,
+		},
 		"volumes defined, empty buildsDir, clone strategy, duplicated error on user volume": {
 			volumes:     []string{"/volume"},
 			gitStrategy: "clone",
 			volumesManagerAssertions: func(vm *volumes.MockManager) {
-				vm.On("Create", "/volume").
+				vm.On("Create", mock.Anything, "/volume").
 					Return(volumes.NewErrVolumeAlreadyDefined("/volume")).
 					Once()
 			},
@@ -764,7 +779,7 @@ func TestCreateVolumes(t *testing.T) {
 			volumes:     []string{"/volume"},
 			gitStrategy: "clone",
 			volumesManagerAssertions: func(vm *volumes.MockManager) {
-				vm.On("Create", "/volume").
+				vm.On("Create", mock.Anything, "/volume").
 					Return(errors.New("test-error")).
 					Once()
 			},
@@ -792,7 +807,7 @@ func TestCreateBuildVolume(t *testing.T) {
 		"git strategy clone, empty buildsDir, no error": {
 			gitStrategy: "clone",
 			volumesManagerAssertions: func(vm *volumes.MockManager) {
-				vm.On("CreateTemporary", volumesTestsDefaultBuildsDir).
+				vm.On("CreateTemporary", mock.Anything, volumesTestsDefaultBuildsDir).
 					Return(nil).
 					Once()
 			},
@@ -801,7 +816,7 @@ func TestCreateBuildVolume(t *testing.T) {
 		"git strategy clone, empty buildsDir, duplicated error": {
 			gitStrategy: "clone",
 			volumesManagerAssertions: func(vm *volumes.MockManager) {
-				vm.On("CreateTemporary", volumesTestsDefaultBuildsDir).
+				vm.On("CreateTemporary", mock.Anything, volumesTestsDefaultBuildsDir).
 					Return(volumes.NewErrVolumeAlreadyDefined(volumesTestsDefaultBuildsDir)).
 					Once()
 			},
@@ -810,7 +825,7 @@ func TestCreateBuildVolume(t *testing.T) {
 		"git strategy clone, empty buildsDir, other error": {
 			gitStrategy: "clone",
 			volumesManagerAssertions: func(vm *volumes.MockManager) {
-				vm.On("CreateTemporary", volumesTestsDefaultBuildsDir).
+				vm.On("CreateTemporary", mock.Anything, volumesTestsDefaultBuildsDir).
 					Return(errors.New("test-error")).
 					Once()
 			},
@@ -821,7 +836,7 @@ func TestCreateBuildVolume(t *testing.T) {
 			gitStrategy: "clone",
 			buildsDir:   "/builds",
 			volumesManagerAssertions: func(vm *volumes.MockManager) {
-				vm.On("CreateTemporary", "/builds").
+				vm.On("CreateTemporary", mock.Anything, "/builds").
 					Return(nil).
 					Once()
 			},
@@ -831,7 +846,7 @@ func TestCreateBuildVolume(t *testing.T) {
 			gitStrategy: "clone",
 			buildsDir:   "/builds",
 			volumesManagerAssertions: func(vm *volumes.MockManager) {
-				vm.On("CreateTemporary", "/builds").
+				vm.On("CreateTemporary", mock.Anything, "/builds").
 					Return(volumes.NewErrVolumeAlreadyDefined("/builds")).
 					Once()
 			},
@@ -841,7 +856,7 @@ func TestCreateBuildVolume(t *testing.T) {
 			gitStrategy: "clone",
 			buildsDir:   "/builds",
 			volumesManagerAssertions: func(vm *volumes.MockManager) {
-				vm.On("CreateTemporary", "/builds").
+				vm.On("CreateTemporary", mock.Anything, "/builds").
 					Return(errors.New("test-error")).
 					Once()
 			},
@@ -851,7 +866,7 @@ func TestCreateBuildVolume(t *testing.T) {
 		"git strategy fetch, empty buildsDir, no error": {
 			gitStrategy: "fetch",
 			volumesManagerAssertions: func(vm *volumes.MockManager) {
-				vm.On("Create", volumesTestsDefaultBuildsDir).
+				vm.On("Create", mock.Anything, volumesTestsDefaultBuildsDir).
 					Return(nil).
 					Once()
 			},
@@ -860,7 +875,7 @@ func TestCreateBuildVolume(t *testing.T) {
 		"git strategy fetch, empty buildsDir, duplicated error": {
 			gitStrategy: "fetch",
 			volumesManagerAssertions: func(vm *volumes.MockManager) {
-				vm.On("Create", volumesTestsDefaultBuildsDir).
+				vm.On("Create", mock.Anything, volumesTestsDefaultBuildsDir).
 					Return(volumes.NewErrVolumeAlreadyDefined(volumesTestsDefaultBuildsDir)).
 					Once()
 			},
@@ -869,7 +884,7 @@ func TestCreateBuildVolume(t *testing.T) {
 		"git strategy fetch, empty buildsDir, other error": {
 			gitStrategy: "fetch",
 			volumesManagerAssertions: func(vm *volumes.MockManager) {
-				vm.On("Create", volumesTestsDefaultBuildsDir).
+				vm.On("Create", mock.Anything, volumesTestsDefaultBuildsDir).
 					Return(errors.New("test-error")).
 					Once()
 			},
@@ -880,7 +895,7 @@ func TestCreateBuildVolume(t *testing.T) {
 			gitStrategy: "fetch",
 			buildsDir:   "/builds",
 			volumesManagerAssertions: func(vm *volumes.MockManager) {
-				vm.On("Create", "/builds").
+				vm.On("Create", mock.Anything, "/builds").
 					Return(nil).
 					Once()
 			},
@@ -890,17 +905,27 @@ func TestCreateBuildVolume(t *testing.T) {
 			gitStrategy: "fetch",
 			buildsDir:   "/builds",
 			volumesManagerAssertions: func(vm *volumes.MockManager) {
-				vm.On("Create", "/builds").
+				vm.On("Create", mock.Anything, "/builds").
 					Return(volumes.NewErrVolumeAlreadyDefined("/builds")).
 					Once()
 			},
 			createVolumeManager: true,
 		},
+		"git strategy fetch, non-empty buildsDir, wrapped duplicated error": {
+			gitStrategy: "fetch",
+			buildsDir:   "/builds",
+			volumesManagerAssertions: func(vm *volumes.MockManager) {
+				vm.On("Create", mock.Anything, "/builds").
+					Return(fmt.Errorf("wrap: %w", volumes.NewErrVolumeAlreadyDefined("/builds"))).
+					Once()
+			},
+			createVolumeManager: true,
+		},
 		"git strategy fetch, non-empty buildsDir, other error": {
 			gitStrategy: "fetch",
 			buildsDir:   "/builds",
 			volumesManagerAssertions: func(vm *volumes.MockManager) {
-				vm.On("Create", "/builds").
+				vm.On("Create", mock.Anything, "/builds").
 					Return(errors.New("test-error")).
 					Once()
 			},
@@ -911,10 +936,23 @@ func TestCreateBuildVolume(t *testing.T) {
 			gitStrategy: "fetch",
 			buildsDir:   "/builds",
 			volumesManagerAssertions: func(vm *volumes.MockManager) {
-				vm.On("Create", "/builds").
+				vm.On("Create", mock.Anything, "/builds").
 					Return(volumes.ErrCacheVolumesDisabled).
 					Once()
-				vm.On("CreateTemporary", "/builds").
+				vm.On("CreateTemporary", mock.Anything, "/builds").
+					Return(nil).
+					Once()
+			},
+			createVolumeManager: true,
+		},
+		"git strategy fetch, non-empty buildsDir, cache volumes disabled wrapped error": {
+			gitStrategy: "fetch",
+			buildsDir:   "/builds",
+			volumesManagerAssertions: func(vm *volumes.MockManager) {
+				vm.On("Create", mock.Anything, "/builds").
+					Return(fmt.Errorf("wrap: %w", volumes.ErrCacheVolumesDisabled)).
+					Once()
+				vm.On("CreateTemporary", mock.Anything, "/builds").
 					Return(nil).
 					Once()
 			},
@@ -924,10 +962,10 @@ func TestCreateBuildVolume(t *testing.T) {
 			gitStrategy: "fetch",
 			buildsDir:   "/builds",
 			volumesManagerAssertions: func(vm *volumes.MockManager) {
-				vm.On("Create", "/builds").
+				vm.On("Create", mock.Anything, "/builds").
 					Return(volumes.ErrCacheVolumesDisabled).
 					Once()
-				vm.On("CreateTemporary", "/builds").
+				vm.On("CreateTemporary", mock.Anything, "/builds").
 					Return(volumes.NewErrVolumeAlreadyDefined("/builds")).
 					Once()
 			},
@@ -944,7 +982,7 @@ func TestCreateBuildVolume(t *testing.T) {
 				})
 			},
 			volumesManagerAssertions: func(vm *volumes.MockManager) {
-				vm.On("Create", "/builds/group").
+				vm.On("Create", mock.Anything, "/builds/group").
 					Return(nil).
 					Once()
 			},
@@ -961,7 +999,7 @@ func TestCreateBuildVolume(t *testing.T) {
 				})
 			},
 			volumesManagerAssertions: func(vm *volumes.MockManager) {
-				vm.On("CreateTemporary", "/builds/group").
+				vm.On("CreateTemporary", mock.Anything, "/builds/group").
 					Return(nil).
 					Once()
 			},
@@ -981,6 +1019,12 @@ func TestCreateBuildVolume(t *testing.T) {
 }
 
 func TestCreateDependencies(t *testing.T) {
+	containerNameRegex, err := regexp.Compile("runner-abcdef12-project-0-concurrent-0-[^-]+-alpine-0")
+	require.NoError(t, err)
+
+	containerNameMatcher := mock.MatchedBy(func(containerName string) bool {
+		return containerNameRegex.MatchString(containerName)
+	})
 	testError := errors.New("test-error")
 
 	tests := map[string]struct {
@@ -1020,16 +1064,16 @@ func TestCreateDependencies(t *testing.T) {
 				volumesManagerAssertions: func(vm *volumes.MockManager) {
 					binds := make([]string, 0)
 
-					vm.On("CreateTemporary", "/builds").
+					vm.On("CreateTemporary", mock.Anything, "/builds").
 						Return(nil).
 						Run(func(args mock.Arguments) {
-							binds = append(binds, args.Get(0).(string))
+							binds = append(binds, args.Get(1).(string))
 						}).
 						Once()
-					vm.On("Create", "/volume").
+					vm.On("Create", mock.Anything, "/volume").
 						Return(nil).
 						Run(func(args mock.Arguments) {
-							binds = append(binds, args.Get(0).(string))
+							binds = append(binds, args.Get(1).(string))
 						}).
 						Maybe() // In the FF enabled case this assertion will be not met because of error during service starts
 					vm.On("Binds").
@@ -1037,11 +1081,8 @@ func TestCreateDependencies(t *testing.T) {
 							return binds
 						}).
 						Once()
-					vm.On("ContainerIDs").
-						Return(nil).
-						Once()
 				},
-				clientAssertions: func(c *docker_helpers.MockClient) {
+				clientAssertions: func(c *docker.MockClient) {
 					hostConfigMatcher := mock.MatchedBy(func(conf *container.HostConfig) bool {
 						return assert.Equal(t, test.expectedServiceVolumes, conf.Binds)
 					})
@@ -1052,10 +1093,10 @@ func TestCreateDependencies(t *testing.T) {
 					c.On("NetworkList", mock.Anything, mock.Anything).
 						Return(nil, nil).
 						Once()
-					c.On("ContainerRemove", mock.Anything, "runner-abcdef12-project-0-concurrent-0-alpine-0", mock.Anything).
+					c.On("ContainerRemove", mock.Anything, containerNameMatcher, mock.Anything).
 						Return(nil).
 						Once()
-					c.On("ContainerCreate", mock.Anything, mock.Anything, hostConfigMatcher, mock.Anything, "runner-abcdef12-project-0-concurrent-0-alpine-0").
+					c.On("ContainerCreate", mock.Anything, mock.Anything, hostConfigMatcher, mock.Anything, containerNameMatcher).
 						Return(container.ContainerCreateCreatedBody{ID: "container-ID"}, nil).
 						Once()
 					c.On("ContainerStart", mock.Anything, "container-ID", mock.Anything).
@@ -1084,9 +1125,9 @@ func getAuthConfigTestExecutor(t *testing.T, precreateConfigFile bool) executor
 		dockerConfigFile := path.Join(tempHomeDir, ".dockercfg")
 		err = ioutil.WriteFile(dockerConfigFile, []byte(testFileAuthConfigs), 0600)
 		require.NoError(t, err)
-		docker_helpers.HomeDirectory = tempHomeDir
+		docker.HomeDirectory = tempHomeDir
 	} else {
-		docker_helpers.HomeDirectory = ""
+		docker.HomeDirectory = ""
 	}
 
 	e := executor{}
@@ -1280,14 +1321,14 @@ func TestAuthConfigOverwritingOrder(t *testing.T) {
 	})
 }
 
-func testGetDockerImage(t *testing.T, e executor, imageName string, setClientExpectations func(c *docker_helpers.MockClient, imageName string)) {
+func testGetDockerImage(t *testing.T, e executor, imageName string, setClientExpectations func(c *docker.MockClient, imageName string)) {
 	t.Run("get:"+imageName, func(t *testing.T) {
-		var c docker_helpers.MockClient
+		c := new(docker.MockClient)
 		defer c.AssertExpectations(t)
 
-		e.client = &c
+		e.client = c
 
-		setClientExpectations(&c, imageName)
+		setClientExpectations(c, imageName)
 
 		image, err := e.getDockerImage(imageName)
 		assert.NoError(t, err, "Should not generate error")
@@ -1295,27 +1336,27 @@ func testGetDockerImage(t *testing.T, e executor, imageName string, setClientExp
 	})
 }
 
-func testDeniesDockerImage(t *testing.T, e executor, imageName string, setClientExpectations func(c *docker_helpers.MockClient, imageName string)) {
+func testDeniesDockerImage(t *testing.T, e executor, imageName string, setClientExpectations func(c *docker.MockClient, imageName string)) {
 	t.Run("deny:"+imageName, func(t *testing.T) {
-		var c docker_helpers.MockClient
+		c := new(docker.MockClient)
 		defer c.AssertExpectations(t)
 
-		e.client = &c
+		e.client = c
 
-		setClientExpectations(&c, imageName)
+		setClientExpectations(c, imageName)
 
 		_, err := e.getDockerImage(imageName)
 		assert.Error(t, err, "Should generate error")
 	})
 }
 
-func addFindsLocalImageExpectations(c *docker_helpers.MockClient, imageName string) {
+func addFindsLocalImageExpectations(c *docker.MockClient, imageName string) {
 	c.On("ImageInspectWithRaw", mock.Anything, imageName).
 		Return(types.ImageInspect{ID: "this-image"}, nil, nil).
 		Once()
 }
 
-func addPullsRemoteImageExpectations(c *docker_helpers.MockClient, imageName string) {
+func addPullsRemoteImageExpectations(c *docker.MockClient, imageName string) {
 	c.On("ImageInspectWithRaw", mock.Anything, imageName).
 		Return(types.ImageInspect{ID: "not-this-image"}, nil, nil).
 		Once()
@@ -1329,7 +1370,7 @@ func addPullsRemoteImageExpectations(c *docker_helpers.MockClient, imageName str
 		Once()
 }
 
-func addDeniesPullExpectations(c *docker_helpers.MockClient, imageName string) {
+func addDeniesPullExpectations(c *docker.MockClient, imageName string) {
 	c.On("ImageInspectWithRaw", mock.Anything, imageName).
 		Return(types.ImageInspect{ID: "image"}, nil, nil).
 		Once()
@@ -1435,7 +1476,7 @@ func TestDockerWatchOn_1_12_4(t *testing.T) {
 type containerConfigExpectations func(*testing.T, *container.Config, *container.HostConfig)
 
 type dockerConfigurationTestFakeDockerClient struct {
-	docker_helpers.MockClient
+	docker.MockClient
 
 	cce containerConfigExpectations
 	t   *testing.T
@@ -1475,8 +1516,6 @@ func prepareTestDockerConfiguration(t *testing.T, dockerConfig *common.DockerCon
 	})
 	require.NoError(t, err)
 
-	c.On("ImageInspectWithRaw", mock.Anything, "gitlab/gitlab-runner-helper:x86_64-latest").
-		Return(types.ImageInspect{ID: "helper-image-id"}, nil, nil).Once()
 	c.On("ImageInspectWithRaw", mock.Anything, "alpine").
 		Return(types.ImageInspect{ID: "123"}, []byte{}, nil).Twice()
 	c.On("ImagePullBlocking", mock.Anything, "alpine:latest", mock.Anything).
@@ -1695,7 +1734,7 @@ func TestDockerSysctlsSetting(t *testing.T) {
 }
 
 type networksTestCase struct {
-	clientAssertions          func(*docker_helpers.MockClient)
+	clientAssertions          func(*docker.MockClient)
 	networksManagerAssertions func(*networks.MockManager)
 	createNetworkManager      bool
 	networkPerBuild           string
@@ -1768,7 +1807,7 @@ func TestDockerCreateNetwork(t *testing.T) {
 		"removing container failed": {
 			createNetworkManager: true,
 			networkPerBuild:      "true",
-			clientAssertions: func(c *docker_helpers.MockClient) {
+			clientAssertions: func(c *docker.MockClient) {
 				c.On("NetworkList", mock.Anything, mock.Anything).
 					Return([]types.NetworkResource{}, nil).
 					Once()
@@ -1831,7 +1870,7 @@ func TestDockerCreateNetwork(t *testing.T) {
 func getExecutorForNetworksTests(t *testing.T, test networksTestCase) (*executor, func()) {
 	t.Helper()
 
-	clientMock := new(docker_helpers.MockClient)
+	clientMock := new(docker.MockClient)
 	networksManagerMock := new(networks.MockManager)
 
 	oldCreateNetworksManager := createNetworksManager
@@ -2072,7 +2111,7 @@ func TestGetServiceDefinitions(t *testing.T) {
 func TestAddServiceHealthCheck(t *testing.T) {
 	tests := map[string]struct {
 		networkMode            string
-		dockerClientAssertions func(*docker_helpers.MockClient)
+		dockerClientAssertions func(*docker.MockClient)
 		expectedEnvironment    []string
 		expectedErr            error
 	}{
@@ -2081,7 +2120,7 @@ func TestAddServiceHealthCheck(t *testing.T) {
 		},
 		"get ports via environment": {
 			networkMode: "test",
-			dockerClientAssertions: func(c *docker_helpers.MockClient) {
+			dockerClientAssertions: func(c *docker.MockClient) {
 				c.On("ContainerInspect", mock.Anything, mock.Anything).
 					Return(types.ContainerJSON{
 						Config: &container.Config{
@@ -2099,7 +2138,7 @@ func TestAddServiceHealthCheck(t *testing.T) {
 		},
 		"get port from many": {
 			networkMode: "test",
-			dockerClientAssertions: func(c *docker_helpers.MockClient) {
+			dockerClientAssertions: func(c *docker.MockClient) {
 				c.On("ContainerInspect", mock.Anything, mock.Anything).
 					Return(types.ContainerJSON{
 						Config: &container.Config{
@@ -2120,7 +2159,7 @@ func TestAddServiceHealthCheck(t *testing.T) {
 		},
 		"no ports defined": {
 			networkMode: "test",
-			dockerClientAssertions: func(c *docker_helpers.MockClient) {
+			dockerClientAssertions: func(c *docker.MockClient) {
 				c.On("ContainerInspect", mock.Anything, mock.Anything).
 					Return(types.ContainerJSON{
 						Config: &container.Config{
@@ -2133,7 +2172,7 @@ func TestAddServiceHealthCheck(t *testing.T) {
 		},
 		"container inspect error": {
 			networkMode: "test",
-			dockerClientAssertions: func(c *docker_helpers.MockClient) {
+			dockerClientAssertions: func(c *docker.MockClient) {
 				c.On("ContainerInspect", mock.Anything, mock.Anything).
 					Return(types.ContainerJSON{}, fmt.Errorf("%v", "test error")).
 					Once()
@@ -2144,7 +2183,7 @@ func TestAddServiceHealthCheck(t *testing.T) {
 
 	for name, test := range tests {
 		t.Run(name, func(t *testing.T) {
-			client := new(docker_helpers.MockClient)
+			client := new(docker.MockClient)
 
 			if test.dockerClientAssertions != nil {
 				test.dockerClientAssertions(client)
@@ -2170,5 +2209,5 @@ func TestAddServiceHealthCheck(t *testing.T) {
 }
 
 func init() {
-	docker_helpers.HomeDirectory = ""
+	docker.HomeDirectory = ""
 }
