@@ -11,7 +11,7 @@ import (
 	"github.com/stretchr/testify/mock"
 
 	"gitlab.com/gitlab-org/gitlab-runner/common"
-	docker_helpers "gitlab.com/gitlab-org/gitlab-runner/helpers/docker"
+	"gitlab.com/gitlab-org/gitlab-runner/helpers/docker"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/featureflags"
 )
 
@@ -45,8 +45,8 @@ func newDefaultManager() *manager {
 	return m
 }
 
-func addClient(manager *manager) *docker_helpers.MockClient {
-	client := new(docker_helpers.MockClient)
+func addClient(manager *manager) *docker.MockClient {
+	client := new(docker.MockClient)
 
 	manager.client = client
 
@@ -60,7 +60,7 @@ func TestCreateNetwork(t *testing.T) {
 		buildNetwork        types.NetworkResource
 		expectedNetworkMode container.NetworkMode
 		expectedErr         error
-		clientAssertions    func(*docker_helpers.MockClient)
+		clientAssertions    func(*docker.MockClient)
 	}{
 		"network specified": {
 			networkMode:         "default",
@@ -80,7 +80,7 @@ func TestCreateNetwork(t *testing.T) {
 			networkMode:         "",
 			networkPerBuild:     "true",
 			expectedNetworkMode: container.NetworkMode("runner--project-0-concurrent-0-job-0-network"),
-			clientAssertions: func(mc *docker_helpers.MockClient) {
+			clientAssertions: func(mc *docker.MockClient) {
 				mc.On("NetworkCreate", mock.Anything, mock.AnythingOfType("string"), mock.AnythingOfType("types.NetworkCreate")).
 					Return(types.NetworkCreateResponse{ID: "test-network"}, nil).
 					Once()
@@ -98,7 +98,7 @@ func TestCreateNetwork(t *testing.T) {
 			networkPerBuild:     "true",
 			expectedNetworkMode: "",
 			expectedErr:         errors.New("test-network failed"),
-			clientAssertions: func(mc *docker_helpers.MockClient) {
+			clientAssertions: func(mc *docker.MockClient) {
 				mc.On("NetworkCreate", mock.Anything, mock.AnythingOfType("string"), mock.AnythingOfType("types.NetworkCreate")).
 					Return(types.NetworkCreateResponse{ID: "test-network"}, errors.New("test-network failed")).
 					Once()
@@ -110,7 +110,7 @@ func TestCreateNetwork(t *testing.T) {
 			networkPerBuild:     "true",
 			expectedNetworkMode: "",
 			expectedErr:         errors.New("network-inspect-failed"),
-			clientAssertions: func(mc *docker_helpers.MockClient) {
+			clientAssertions: func(mc *docker.MockClient) {
 				mc.On("NetworkCreate", mock.Anything, mock.AnythingOfType("string"), mock.AnythingOfType("types.NetworkCreate")).
 					Return(types.NetworkCreateResponse{ID: "test-network"}, nil).
 					Once()
@@ -163,7 +163,7 @@ func TestInspectNetwork(t *testing.T) {
 
 	testCases := map[string]struct {
 		perBuild         bool
-		clientAssertions func(client *docker_helpers.MockClient)
+		clientAssertions func(client *docker.MockClient)
 		expectedResponse types.NetworkResource
 		expectedErr      error
 	}{
@@ -174,7 +174,7 @@ func TestInspectNetwork(t *testing.T) {
 		},
 		"no network per build": {
 			perBuild: true,
-			clientAssertions: func(m *docker_helpers.MockClient) {
+			clientAssertions: func(m *docker.MockClient) {
 				m.On("NetworkInspect", mock.Anything, mock.AnythingOfType("string")).
 					Return(types.NetworkResource{
 						ID:   networkName,
@@ -190,7 +190,7 @@ func TestInspectNetwork(t *testing.T) {
 		},
 		"network inspect failed": {
 			perBuild: true,
-			clientAssertions: func(m *docker_helpers.MockClient) {
+			clientAssertions: func(m *docker.MockClient) {
 				m.On("NetworkInspect", mock.Anything, mock.AnythingOfType("string")).
 					Return(types.NetworkResource{}, testError)
 			},
@@ -224,7 +224,7 @@ func TestCleanupNetwork(t *testing.T) {
 	testCases := map[string]struct {
 		networkMode      string
 		networkPerBuild  string
-		clientAssertions func(*docker_helpers.MockClient)
+		clientAssertions func(*docker.MockClient)
 		expectErr        error
 	}{
 		"network per-build flag off": {
@@ -236,7 +236,7 @@ func TestCleanupNetwork(t *testing.T) {
 		},
 		"cleanup per-build network": {
 			networkPerBuild: "true",
-			clientAssertions: func(mc *docker_helpers.MockClient) {
+			clientAssertions: func(mc *docker.MockClient) {
 				mc.On("NetworkRemove", mock.Anything, mock.AnythingOfType("string")).
 					Return(nil).
 					Once()
@@ -244,7 +244,7 @@ func TestCleanupNetwork(t *testing.T) {
 		},
 		"cleanup per-build error": {
 			networkPerBuild: "true",
-			clientAssertions: func(mc *docker_helpers.MockClient) {
+			clientAssertions: func(mc *docker.MockClient) {
 				mc.On("NetworkRemove", mock.Anything, mock.AnythingOfType("string")).
 					Return(testErr).
 					Once()
