@@ -325,6 +325,7 @@ func getRequestJobResponse() (res map[string]interface{}) {
 	variables[0]["value"] = "master"
 	variables[0]["public"] = true
 	variables[0]["file"] = true
+	variables[0]["raw"] = true
 	res["variables"] = variables
 
 	steps := make([]map[string]interface{}, 2)
@@ -491,6 +492,13 @@ func TestRequestJob(t *testing.T) {
 	assert.Equal(t, "mysql:5.6", res.Services[1].Name)
 	assert.Equal(t, "db-mysql", res.Services[1].Alias)
 
+	require.Len(t, res.Variables, 1)
+	assert.Equal(t, "CI_REF_NAME", res.Variables[0].Key)
+	assert.Equal(t, "master", res.Variables[0].Value)
+	assert.True(t, res.Variables[0].Public)
+	assert.True(t, res.Variables[0].File)
+	assert.True(t, res.Variables[0].Raw)
+
 	assert.Empty(t, c.getLastUpdate(&noJobsToken.RunnerCredentials), "Last-Update should not be set")
 	res, ok = c.RequestJob(noJobsToken, nil)
 	assert.Nil(t, res)
@@ -1251,7 +1259,7 @@ func TestRunnerVersionToGetExecutorAndShellFeaturesWithTheDefaultShell(t *testin
 		features := args[0].(*FeaturesInfo)
 		features.Shared = true
 	})
-	RegisterExecutor("my-test-executor", &executorProvider)
+	RegisterExecutorProvider("my-test-executor", &executorProvider)
 
 	shell := MockShell{}
 	defer shell.AssertExpectations(t)
